BOOST_PP_LIST_NIL

The BOOST_PP_LIST_NIL macro is a nil list constructor.

#### Usage

BOOST_PP_LIST_NIL

#### Remarks

This macro represents the end of a list.
This macro is no longer necessary. It simply expands to BOOST_PP_NIL. Because of this, this macro is deprecated.

#### See Also

- BOOST_PP_NIL

#### Requirements

Header: <boost/preprocessor/list/adt.hpp>

#### Sample Code

    #include <boost/preprocessor/list/adt.hpp>

    #define OLD \
       BOOST_PP_LIST_CONS( \
          a, \
          BOOST_PP_LIST_CONS( \
             b, \
             BOOST_PP_LIST_CONS( \
                c, \
                BOOST_PP_LIST_NIL \
             ) \
          ) \
       ) \
       /**/

    #define NEW (a, (b, (c, BOOST_PP_NIL)))

    BOOST_PP_LIST_FIRST(OLD) == BOOST_PP_LIST_FIRST(NEW)
       // expands to a == a

    BOOST_PP_LIST_REST(OLD) == BOOST_PP_LIST_RESTK(NEW)
       // expands to (b, (c, BOOST_PP_NIL)) == (b, (c, BOOST_PP_NIL))

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)